@@ -101,70 +101,57 @@ MOCK_LOG_PAYLOAD = "Log line 1\nLog line 2"
 
 
 @patch("cytetype.client.time.sleep", return_value=None)  # Prevent actual sleep
-@patch("cytetype.client.requests.get")
-def test_poll_for_results_success(mock_get: MagicMock, mock_sleep: MagicMock) -> None:
+@patch("cytetype.client.make_results_request")
+def test_poll_for_results_success(
+    mock_make_results: MagicMock, mock_sleep: MagicMock
+) -> None:
     """Test successful polling completion."""
-    mock_response_pending = MagicMock(spec=requests.Response)
-    mock_response_pending.status_code = 200
-    mock_response_pending.json.return_value = {"status": "pending"}
-
-    # Mock response for the log call
-    mock_response_logs = MagicMock(spec=requests.Response)
-    mock_response_logs.status_code = 200
-    mock_response_logs.text = MOCK_LOG_PAYLOAD
-
-    mock_response_complete = MagicMock(spec=requests.Response)
-    mock_response_complete.status_code = 200
-    mock_response_complete.json.return_value = {
-        "status": "completed",
-        "result": MOCK_RESULT_PAYLOAD,
-    }
-
-    # Update side_effect to include log response
-    mock_get.side_effect = [
-        mock_response_pending,  # First call to /retrieve
-        mock_response_logs,  # First call to /display_logs
-        mock_response_complete,  # Second call to /retrieve
+    # Mock sequence: pending -> completed
+    mock_make_results.side_effect = [
+        {
+            "status": "pending",
+            "result": None,
+            "message": "Job is pending",
+            "raw_response": {"clusterStatus": {}},
+        },
+        {
+            "status": "completed",
+            "result": MOCK_RESULT_PAYLOAD,
+            "message": "Job completed successfully",
+            "raw_response": {"clusterStatus": {}},
+        },
     ]
 
     result = poll_for_results(MOCK_JOB_ID, DEFAULT_API_URL, poll_interval=1, timeout=5)
 
     assert result == MOCK_RESULT_PAYLOAD
-    # Correct the expected URLs and add timeout arg
-    results_url = f"{DEFAULT_API_URL}/results/{MOCK_JOB_ID}"
-    logs_url = f"{DEFAULT_API_URL}/logs/{MOCK_JOB_ID}"
-    expected_calls = [
-        call(results_url, headers={}, timeout=30),  # First results call
-        call(logs_url, headers={}, timeout=10),  # Log call
-        call(results_url, headers={}, timeout=30),  # Second results call
-    ]
-    mock_get.assert_has_calls(expected_calls)
-    # Check that sleep was called for initial delay and poll interval
-    expected_sleep_calls = [call(20), call(1)]
+    # Should be called twice - once for pending, once for completed
+    assert mock_make_results.call_count == 2
+    # Check that sleep was called for initial delay and poll interval (0.5s x 2 for 1s poll interval)
+    expected_sleep_calls = [call(5), call(0.5), call(0.5)]
     mock_sleep.assert_has_calls(expected_sleep_calls)
 
 
 @patch("cytetype.client.time.sleep", return_value=None)
-@patch("cytetype.client.requests.get")
+@patch("cytetype.client.make_results_request")
 def test_poll_for_results_error_status(
-    mock_get: MagicMock, mock_sleep: MagicMock
+    mock_make_results: MagicMock, mock_sleep: MagicMock
 ) -> None:
     """Test polling when API returns an 'error' status."""
-    mock_response_error = MagicMock()
-    mock_response_error.status_code = 200
-    mock_response_error.json.return_value = {
-        "status": "error",
+    mock_make_results.return_value = {
+        "status": "failed",
+        "result": None,
         "message": "Annotation failed internally",
+        "raw_response": {"clusterStatus": {}},
     }
-    mock_get.return_value = mock_response_error
 
     with pytest.raises(
         CyteTypeJobError, match="Server error: Annotation failed internally"
     ):
         poll_for_results(MOCK_JOB_ID, DEFAULT_API_URL, poll_interval=1, timeout=5)
-    mock_get.assert_called_once()
-    # Assert only the initial sleep(20) happened
-    mock_sleep.assert_called_once_with(20)
+    mock_make_results.assert_called_once()
+    # Assert only the initial sleep(5) happened
+    mock_sleep.assert_called_once_with(5)
 
 
 @patch("cytetype.client.time.sleep", return_value=None)
@@ -246,24 +233,26 @@ def test_poll_for_results_invalid_json(
 
 
 @patch("cytetype.client.time.sleep", return_value=None)
-@patch("cytetype.client.requests.get")
+@patch("cytetype.client.make_results_request")
 def test_poll_for_results_missing_keys(
-    mock_get: MagicMock, mock_sleep: MagicMock
+    mock_make_results: MagicMock, mock_sleep: MagicMock
 ) -> None:
     """Test polling failure due to missing keys in 'completed' response."""
-    mock_response_complete = MagicMock()
-    mock_response_complete.status_code = 200
-    # Status is correct, but missing 'result' key
-    mock_response_complete.json.return_value = {"status": "completed"}
-    mock_get.return_value = mock_response_complete
+    # Status is failed due to invalid response format
+    mock_make_results.return_value = {
+        "status": "failed",
+        "result": None,
+        "message": "Invalid response format from API",
+        "raw_response": {"clusterStatus": {}},
+    }
 
     with pytest.raises(
         CyteTypeJobError, match="Server error: Invalid response format from API"
     ):
         poll_for_results(MOCK_JOB_ID, DEFAULT_API_URL, poll_interval=1, timeout=5)
-    mock_get.assert_called_once()
-    # Assert only the initial sleep(20) happened
-    mock_sleep.assert_called_once_with(20)
+    mock_make_results.assert_called_once()
+    # Assert only the initial sleep(5) happened
+    mock_sleep.assert_called_once_with(5)
 
 
 # --- Test auth_token functionality ---
@@ -295,18 +284,17 @@ def test_submit_job_with_auth_token(mock_post: MagicMock) -> None:
 
 
 @patch("cytetype.client.time.sleep", return_value=None)
-@patch("cytetype.client.requests.get")
+@patch("cytetype.client.make_results_request")
 def test_poll_for_results_with_auth_token(
-    mock_get: MagicMock, mock_sleep: MagicMock
+    mock_make_results: MagicMock, mock_sleep: MagicMock
 ) -> None:
-    """Test poll_for_results with auth_token includes Bearer token in headers."""
-    mock_response_complete = MagicMock(spec=requests.Response)
-    mock_response_complete.status_code = 200
-    mock_response_complete.json.return_value = {
+    """Test poll_for_results with auth_token passes it to make_results_request."""
+    mock_make_results.return_value = {
         "status": "completed",
         "result": MOCK_RESULT_PAYLOAD,
+        "message": "Job completed successfully",
+        "raw_response": {"clusterStatus": {}},
     }
-    mock_get.return_value = mock_response_complete
 
     auth_token = "test-bearer-token-456"
     result = poll_for_results(
@@ -315,7 +303,5 @@ def test_poll_for_results_with_auth_token(
 
     assert result == MOCK_RESULT_PAYLOAD
 
-    # Check that Authorization header is included in the call
-    results_url = f"{DEFAULT_API_URL}/results/{MOCK_JOB_ID}"
-    expected_headers = {"Authorization": f"Bearer {auth_token}"}
-    mock_get.assert_called_once_with(results_url, headers=expected_headers, timeout=30)
+    # Check that auth_token is passed to make_results_request
+    mock_make_results.assert_called_once_with(MOCK_JOB_ID, DEFAULT_API_URL, auth_token)
